# matlablib
Suite of Matlab utilities ported over to Python 

## Installation
Run the following to install :

```python
pip install matlablib
```


## Usage
``` python
import matlablib as ml  
from matlablib import closefigures  
from matlablib import cc  
from matlablib import keyboard  
from matlablib import sayHey  
from matlablib import quit_early  
from matlablib import kill_background  
from matlablib import getPythonVariables  
```

### Say hey
``` python
ml.sayHey
```
